clear;clc;

% Load GDP data

load data_BOE YBHA3 debt_boe % GDP is 1700-2017, Debt is 1691-2016
startyearGDP=1700;

% Load Quantity data (Q3 and Q4 contain different gilts)

Q1 = dataset('XLSFile','Q_1694m3-1860m2.xlsx');
Q2 = dataset('XLSFile','Q_1860m3-1881m2.xlsx');
Q3 = dataset('XLSFile','Q_1881m1-1947m12.xlsx');
Q4 = dataset('XLSFile','Q_1900m11-1947m12.xlsx');
Q5 = dataset('XLSFile','Q_1946m1-2018m12.xlsx');
Q=[Q1;Q2(Q2.Year<1881,:);Q3;Q4;Q5(Q5.Year>1947,:)];

% Load Price data

P1 = dataset('XLSFile','P_1729m7-1860m2.xlsx');
P2 = dataset('XLSFile','P_1860m3-1888m2.xlsx');
P3 = dataset('XLSFile','P_1881m1-1949m3.xlsx');
P4 = dataset('XLSFile','P_1949m1-1962m12.xlsx');
P5 = dataset('XLSFile','P_1963m1-1975m12.xlsx');
P6 = dataset('XLSFile','P_1976m1-2018m12.xlsx');
P=[P1;P2(P2.Year<1888,:);P3(P3.Year<1949,:);P4;P5;P6];

% Define period of interest

startyear=1729;
endyear=2017;

% Define variables to store results

debt_face=zeros((endyear-startyear+1)*12,1);
debt_market=zeros((endyear-startyear+1)*12,1);
debt_face_a=zeros(endyear-startyear,1);
debt_market_a=zeros(endyear-startyear,1);
index_for_debt=zeros((endyear-startyear+1)*12,2);
index_for_debt_a=zeros(endyear-startyear,1);

% Loop through years and months

for year=startyear:endyear
    
    if year==endyear
        endmonth=12; % Data ends 2018m12
    else
        endmonth=12;
    end
    
    for month=1:endmonth
        
        [year,month]
        
        % Store year and month
        
        index_for_debt((year-startyear)*12+month,1)=year;
        index_for_debt((year-startyear)*12+month,2)=month;   
         
        % Select gilts for which quantity>0 in year and month

        Qtemp=Q(Q.Year==year & Q.Month==month & Q.Q>0,:);
        n=length(Qtemp);

        % Variables to store prices and quantity

        P1=zeros(n,1);
        P2=zeros(n,1);
        Q2=zeros(n,1);
        
        % Calculate market and face value if at least one gilt in market

        if isempty(Qtemp)
            % No gilts in market in period
            debt_face((year-startyear)*12+month)=0;
            debt_market((year-startyear)*12+month)=0;
        else
            % Loop through list of gilts in market
            for i=1:n
                % Look up market price of gilt
                Ptemp=P.P(P.Year==year & P.Month==month & P.ID==Qtemp.ID(i),:);
                if isempty(Ptemp)
                    % Set quantity to zero if no price data
                    P1(i)=1;
                    P2(i)=1;
                    Q2(i)=0;
                else
                    % Price data available
                    P1(i)=Ptemp;    % Market price
                    P2(i)=100;      % Face value
                    Q2(i)=Qtemp.Q(i);
                end
            end
            % Calculate market and face value of all outstanding gilts    
            debt_market((year-startyear)*12+month)=sum(P1.*Q2);
            debt_face((year-startyear)*12+month)=sum(P2.*Q2);
        end

        % If year end then save market and face values (relative to GDP)
    
        if month==12
            debt_market_a(year-startyear+1)=sum(P1.*Q2)/YBHA3(year-startyearGDP+1);
            debt_face_a(year-startyear+1)=sum(P2.*Q2)/YBHA3(year-startyearGDP+1);
            index_for_debt_a(year-startyear+1)=year;
        end
    end
end

% Figure 5: Market and face value of debt

figure(5);
subplot(2,1,1);
plot(index_for_debt_a,[debt_market_a debt_face_a],'LineWidth',1.5);
legend('Market value in data','Par value in data','Location','northwest');
ylabel('Relative to GDP','FontSize',24);
set(gca,'FontSize',24);
xlim([1720 2020]);
subplot(2,1,2);
plot(index_for_debt(:,1)+(1/12)*(index_for_debt(:,2)-1),debt_market./debt_face,'LineWidth',1.5);
ylabel('Market/Par value','FontSize',24);
axis([1720 2020 0.5 1.5]);
set(gca,'FontSize',24);
ylim([0.5 2]);
