clear; clc;

% Load primary surplus /GDP and capital gain on 3% Consol 1730-2014

load surplus_gain surplus_GDP_a gain;

% Remove years when deficit is more than 15% of GDP

n=size(gain,1);
surplus_GDP_a2=zeros(n,1);
gain2=zeros(n,1);
j=1;

for i=1:n
    if surplus_GDP_a(i)>-0.15
        surplus_GDP_a2(j)=surplus_GDP_a(i);
        gain2(j)=gain(i);
        j=j+1;
    else
        i+1729 % Display year removed
    end
end

% Estimate VAR with Ambrogio Cesa-Bianchi's toolkit for VAR analysis

Y=[-surplus_GDP_a2(1:j) gain2(1:j)];
[VAR, VARopt] = VARmodel(Y,2,1);
VARopt.ndraws    = 100; 
VARopt.vnames={ 'Funding' 'Revaluations' };
VARopt.nsteps    = 10;
VARopt.impact    = 0; 
VARopt.pctg      = 95;
[IRF, VAR] = VARir(VAR,VARopt);
[INF,SUP,MED,BAR] = VARirband(VAR,VARopt);

% Figure 8: Primary deficit and revaluation of 3% Treasury

figure(8);

subplot(2,2,1);
plot(-surplus_GDP_a,gain,'bo','MarkerFaceColor','b');
title('(a) Primary deficit vs Revaluation');
xlabel('Primary deficit');
ylabel('Revaluation of Consol');
xlim([-0.2 0.6]);
ylim([-0.4 0.6]);
set(gca,'FontSize',24);

subplot(2,2,2);
plot(1:VARopt.nsteps,0.*IRF(:,2,1),'k','linewidth',1);
hold on;
plot(1:VARopt.nsteps,IRF(:,2,1),'b','linewidth',2);
hold on;
plot(1:VARopt.nsteps,SUP(:,2,1),'b--','linewidth',1.2);
hold on;
plot(1:VARopt.nsteps,INF(:,2,1),'b--','linewidth',1.2);
title('(b) Response to a primary deficit shock');
xlabel('Years');
ylabel('Revaluation of Consol');
ylim([-0.03 0.02]);
set(gca,'FontSize',24);





