% Hall-Sargent decompositions for counterfactuals in Tables 3 and 4

clear;clc;

global Yields Prices YBHA3 YBHA3_real debt_boe startyearGDP endyearGDP;
global Qmonthi startyeari endyeari;

% Load yields and prices for counterfactuals

load ZCY_data.mat Yields Yields_r Prices nominal_index real_index

% Load GDP and debt data

load data_BOE YBHA3 YBHA3_real debt_boe % GDP is 1700-2017, Debt is 1691-2016
startyearGDP=1700; endyearGDP=2017;

% Load issuance data - NEEDS UPDATING

load issuance_f_data Qmonthi startyeari endyeari;

% Pairs of start and end dates for Tables 3 and 4

starts=[1914 1914 1946 1971 1998];
ends=[2017 1945 1970 1997 2017];

% Define arrays to store results

Zstore=zeros(9,size(starts,2));
Zstore_data=zeros(9,size(starts,2));

for ii=1:size(starts,2);

    year1=starts(ii);
    year2=ends(ii);
     
    % Reset nominal payments on nominal fixed-term debt at monthly frequency

    load returns_f_data index_for_pay pay pay1 pay2;
 
    % Reset face and market values of debt at monthly frequency

    load debt_f_data debt_face debt_face_n debt_face_i debt_market ...
    debt_market_n debt_market_i startyear endyear;
    
    % Hall-Sargent decomposition on historical data

    decompose
    
    % Store results and contribution of new debt in data
       
    Zstore_data(:,ii)=Results;
    fund_fix=Results(9);
    
    % Construct counterfactual: select one options
    
    fixed1([36,starts(ii),0]); % 3 year counterfactual without buyback
    %fixed1([60,starts(ii),0]); % 5 year counterfactual without buyback
    %fixed1([120,starts(ii),0]); % 10 year counterfactual without buyback    
    %fixed1bb([36,36-12,starts(ii),0]); % 3 year counterfactual with buyback
    %fixed1bb([60,60-12,starts(ii),0]); % 5 year counterfactual with buyback
    %fixed1bb([120,120-12,starts(ii),0]); % 10 year counterfactual with buyback
    
    % Correct market value of debt to include spare cash in counterfactual
    
    load tempsave1 debt_c cash cash_c;
    Total_debt_mv_c=sum(0.01*debt_c.*Prices,2);
    Total_debt_mv_c=Total_debt_mv_c+((cash_c(1:(endyeari-startyeari+1)*12)-cash(1:(endyeari-startyeari+1)*12))...
        .*((cash_c(1:(endyeari-startyeari+1)*12)-cash(1:(endyeari-startyeari+1)*12))<0));

    % Overwrite data for decompositions.
    
    pay2=pay;
    pay1=0.*pay1;
    debt_market(end-12*(endyeari-startyeari)+1:end)=Total_debt_mv_c(1:end-12);
    debt_market_n(end-12*(endyeari-startyeari)+1:end)=Total_debt_mv_c(1:end-12);
    
    % Hall-Sargent decomposition on counterfactual data
    
    decompose
    
    % Rescale contribution of nominal return so deficit term is constant across counterfactuals
    
    Results(4)=Results(4)-(fund_fix-Results(9));
    Results(6)=Results(6)-(fund_fix-Results(9));
    Results(9)=Results(9)+(fund_fix-Results(9));

    % Store results
    
    Zstore(:,ii)=Results(1:9);

end

Zstore_data=Zstore_data';
Zstore=Zstore';

