% Aggregate and store face and market values of debt at monthly frequency

clear;clc;

% Load Quantity data (Q3 and Q4 contain different gilts)

Q1 = dataset('XLSFile','Q_1694m3-1860m2.xlsx');
Q2 = dataset('XLSFile','Q_1860m3-1881m2.xlsx');
Q3 = dataset('XLSFile','Q_1881m1-1947m12.xlsx');
Q4 = dataset('XLSFile','Q_1900m11-1947m12.xlsx');
Q5 = dataset('XLSFile','Q_1946m1-2018m12.xlsx');
Q=[Q1;Q2(Q2.Year<1881,:);Q3;Q4;Q5(Q5.Year>1947,:)];

% Load Price data

P1 = dataset('XLSFile','P_1729m7-1860m2.xlsx');
P2 = dataset('XLSFile','P_1860m3-1888m2.xlsx');
P3 = dataset('XLSFile','P_1881m1-1949m3.xlsx');
P4 = dataset('XLSFile','P_1949m1-1962m12.xlsx');
P5 = dataset('XLSFile','P_1963m1-1975m12.xlsx');
P6 = dataset('XLSFile','P_1976m1-2018m12.xlsx');
P=[P1;P2(P2.Year<1888,:);P3(P3.Year<1949,:);P4;P5;P6];

% Select only fixed term nominal debt not related to WWI

%Q=Q(Q.ID<32300,:);

% Omit consols

Qlow=Q(Q.ID<32300,:);
Qhigh=Q(Q.ID>32300,:);
% Start and end year of interest

startyear=1692;
endyear=2017;

% Define variables to store results

debt_face=zeros(12*(endyear-startyear+1),1);
debt_face_n=zeros(12*(endyear-startyear+1),1);
debt_face_i=zeros(12*(endyear-startyear+1),1);
debt_market=zeros(12*(endyear-startyear+1),1);
debt_market_n=zeros(12*(endyear-startyear+1),1);
debt_market_i=zeros(12*(endyear-startyear+1),1);

%debt_maturity=zeros(12*(endyear-startyear+1),1);

% Loop through years and months

for year=startyear:endyear
  
    for month=1:12
        
        [year,month]

        % Select bonds for which quantity > 0

        Qtemp=Q(Q.Year==year & Q.Month==month & Q.Q>0,:);
    
        % Define variable to store price

        ID=Qtemp.ID;
        n=size(Qtemp,1);
        P2=zeros(n,1);

        % Look up price
        
        for i=1:n
            Z=P.P(P.Year==year & P.Month==month & P.ID==Qtemp.ID(i),:);
            if isempty(Z)
                P2(i)=0;
            else
                P2(i)=Z;
            end
        end
        
        % Set dummies to classify gilts between indexed and nominal
        
        indexed=(ID>49999).*(ID<60000);
        nominal=1-indexed;
        
        % Total face value of debt, classified indexed and nominal

        debt_face(12*(year-startyear)+month)=sum(100.*Qtemp.Q);
        debt_face_n(12*(year-startyear)+month)=sum(100.*Qtemp.Q.*nominal);
        debt_face_i(12*(year-startyear)+month)=sum(100.*Qtemp.Q.*indexed);
        
        % Total market value of debt, classified indexed and nominal
        
        debt_market(12*(year-startyear)+month)=sum(P2.*Qtemp.Q);
        debt_market_n(12*(year-startyear)+month)=sum(P2.*Qtemp.Q.*nominal);
        debt_market_i(12*(year-startyear)+month)=sum(P2.*Qtemp.Q.*indexed);
        
    end
    
end

% Save face and market values of debt at monthly frequency

save debt_f_data debt_face debt_face_n debt_face_i debt_market ...
     debt_market_n debt_market_i startyear endyear;