% Aggregate and store face values of new issuance at monthly frequency

clear;clc;

% Load Quantity data (Q3 and Q4 contain different gilts)

Q1 = dataset('XLSFile','Q_1694m3-1860m2.xlsx');
Q2 = dataset('XLSFile','Q_1860m3-1881m2.xlsx');
Q3 = dataset('XLSFile','Q_1881m1-1947m12.xlsx');
Q4 = dataset('XLSFile','Q_1900m11-1947m12.xlsx');
Q5 = dataset('XLSFile','Q_1946m1-2018m12.xlsx');
Q=[Q1;Q2(Q2.Year<1881,:);Q3;Q4;Q5(Q5.Year>1947,:)];

% Select only fixed term nominal debt not related to WWI

Q=Q(Q.ID<32300,:);

% Load characteristics of individual gilts

d = dataset('XLSFile','Specification.xlsx');

% Period of interest

startyeari=1915;
endyeari=2018;

% Variable to store results

maxmaturity=80;
Qmonthi=zeros(12*(endyeari-startyeari+1),maxmaturity*12);

% Loop through years and months

for year=startyeari:endyeari
    
    if year==endyeari
        endmonth=12;
    else
        endmonth=12;
    end
    
    for month=1:endmonth
        
        [year,month]
        
        % Convert current date to number
        
        Settle=datenum([year  month  eomday(year,month)  0  0  0]);
                
        % Select bonds for which quantity > 0

        Qtemp=Q(Q.Year==year & Q.Month==month & Q.Q>0,:);

        % Look up quantity, maturity and coupon information

        n=size(Qtemp,1);
        ID=Qtemp.ID;
        Qs=zeros(n,1);
        Maturity=zeros(n,1);
        c=zeros(n,1);
        startQ=zeros(n,2);

        for i=1:n
            Qs(i)=Qtemp.Q(Qtemp.ID==ID(i),:);
            Maturity(i)=datenum(d.Redemption(d.ID==ID(i),:),'dd/mm/yyyy');
            c(i)=Qtemp.Coupon(Qtemp.ID==ID(i),:);
            startQ(i,:)=[d.FirstYearQ(d.ID==ID(i)); d.FirstMonthQ(d.ID==ID(i))];
        end
        
        % Store redemption payments and all coupons of new issuance
        
        Qh_new=zeros(365*maxmaturity,1);
        Qh_top=zeros(365*maxmaturity,1);
        
        for i=1:n
            if startQ(i,:)==[year,month] % Completely new issuance
                Qh_new(Maturity(i)-Settle)=Qh_new(Maturity(i)-Settle)+Qs(i);
                for j=Maturity(i):-365/2:Settle+1
                    Qh_new(round(j-Settle))=Qh_new(round(j-Settle))+c(i)*Qs(i)/200;
                end
            else
                if month==1
                    lastmonth=12;
                    lastyear=year-1;
                else
                    lastmonth=month-1;
                    lastyear=year;
                end
                lastQtemp=Q(Q.Year==lastyear & Q.Month==lastmonth & Q.ID==ID(i),:);
                if lastQtemp.Q<Qs(i) % Top ups
                    Qh_top(Maturity(i)-Settle)=Qh_top(Maturity(i)-Settle)+(Qs(i)-lastQtemp.Q);
                    for j=Maturity(i):-365/2:Settle+1
                        Qh_top(round(j-Settle))=Qh_top(round(j-Settle))+c(i)*(Qs(i)-lastQtemp.Q)/200;
                    end    
                end
            end
        end
        
        % Put maturity structure into monthly bins 

        Qhm_new=zeros(maxmaturity*12,1);
        Qhm_top=zeros(maxmaturity*12,1);
        for i=1:round((max(Maturity)-Settle)*12/365)+1
             Qhm_new(i)=sum(Qh_new(1+round((i-1)*(365/12)):round(i*(365/12))));
             Qhm_top(i)=sum(Qh_top(1+round((i-1)*(365/12)):round(i*(365/12))));
        end
        Qmonthi((year-startyeari)*12+month,:)=Qhm_new'+Qhm_top';
        
    end
end

% Save issuance

save issuance_f_data Qmonthi startyeari endyeari;