% Aggregate and store one period holding returns

clear;clc;

% Load Quantity data (Q3 and Q4 contain different gilts)

Q1 = dataset('XLSFile','Q_1694m3-1860m2.xlsx');
Q2 = dataset('XLSFile','Q_1860m3-1881m2.xlsx');
Q3 = dataset('XLSFile','Q_1881m1-1947m12.xlsx');
Q4 = dataset('XLSFile','Q_1900m11-1947m12.xlsx');
Q5 = dataset('XLSFile','Q_1946m1-2018m12.xlsx');
Q=[Q1;Q2(Q2.Year<1881,:);Q3;Q4;Q5(Q5.Year>1947,:)];

% Load Price data

P1 = dataset('XLSFile','P_1729m7-1860m2.xlsx');
P2 = dataset('XLSFile','P_1860m3-1888m2.xlsx');
P3 = dataset('XLSFile','P_1881m1-1949m3.xlsx');
P4 = dataset('XLSFile','P_1949m1-1962m12.xlsx');
P5 = dataset('XLSFile','P_1963m1-1975m12.xlsx');
P6 = dataset('XLSFile','P_1976m1-2018m12.xlsx');
P=[P1;P2(P2.Year<1888,:);P3(P3.Year<1949,:);P4;P5;P6];

% Start and end year of interest

startyear=1692;
endyear=2018;

% Define variables to store results

pay=zeros(12*(endyear-startyear+1),1);
pay1=zeros(12*(endyear-startyear+1),1);
pay2=zeros(12*(endyear-startyear+1),1);
index_for_pay=zeros(12*(endyear-startyear+1),2);

% Loop through years and months

for year=startyear:endyear
    
    if year==endyear
        endmonth=12;
    else
        endmonth=12;
    end
    
    for month=1:endmonth
        
    [year month]
        
    % Select bonds for which quantity>0

    Qtemp=Q(Q.Year==year & Q.Month==month & Q.Q>0,:);
    
    % Define variable to store prices and coupon
    
    n=size(Qtemp,1);
    P1=zeros(n,1);
    P2=zeros(n,1);
    C=zeros(n,1);

    % Loop through gilts
    
    for i=1:n
    
        % Look up current price and one year ahead price
        
        Z=P.P(P.Year==year & P.Month==month & P.ID==Qtemp.ID(i),:);
        Z2=P.P(P.Year==year+1 & P.Month==month & P.ID==Qtemp.ID(i),:);
        
        % Prices and coupon are zero if no price data
    
        if isempty(Z) || isempty(Z2)
            P1(i)=0;
            P2(i)=0;
            C(i)=0;
        else
            P1(i)=Z;
            P2(i)=Z2;
            C(i)=Qtemp.Coupon(i);
        end
        
    end
    
    % Holding period returns: total, coupons and capital gains/losses
    
    pay(12*(year-startyear)+month)=sum(P2.*Qtemp.Q)-sum(P1.*Qtemp.Q)+sum(C.*Qtemp.Q);
    pay1(12*(year-startyear)+month)=sum(C.*Qtemp.Q);
    pay2(12*(year-startyear)+month)=sum(P2.*Qtemp.Q)-sum(P1.*Qtemp.Q);
    
    % Populate date index
    
    index_for_pay(12*(year-startyear)+month,1)=year+1;
    index_for_pay(12*(year-startyear)+month,2)=month;
    
    end
    
end

% Save holding period returns at monthly frequency

save returns_data index_for_pay pay pay1 pay2;